Contributing
------------

Bug report should be submitted at
https://www.cubicweb.org/project/cubicweb-jsonschema.

Patches should be submitted by email at the cubicweb-devel@lists.cubicweb.org
mailing list as for the CubicWeb_ project (see respective `Contributing`
section for details).

For this project, one should add a ``jsonschema`` flag to message headers;
this can be achieved by specifying a ``--flag jsonschema`` option to ``hg
email`` command.

.. _CubicWeb: https://www.cubicweb.org/project/cubicweb
